<?php

namespace Litepie\Services\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Services\Http\Requests\ServiceRequest;
use Litepie\Services\Interfaces\ServiceRepositoryInterface;
use Litepie\Services\Models\Service;
use Litepie\Services\Forms\Service as Form;

/**
 * APIController  class for service.
 */
class ServiceAPIController extends BaseController
{

    /**
     * Initialize service resource controller.
     *
     * @param type ServiceRepositoryInterface $service
     *
     * @return null
     */
    public function __construct(ServiceRepositoryInterface $service)
    {
        parent::__construct();
        $this->repository = $service;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Services\Repositories\Criteria\ServiceResourceCriteria::class);
    }

    /**
     * Display a list of service.
     *
     * @return Response
     */
    public function index(ServiceRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Services\Repositories\Presenter\ServicePresenter::class)
            ->paginate();
    }

    /**
     * Display service.
     *
     * @param Request $request
     * @param Model   $service
     *
     * @return Response
     */
    public function show(ServiceRequest $request, Service $service)
    {
        return $service->setPresenter(\Litepie\Services\Repositories\Presenter\ServiceListPresenter::class);
        ;
    }

    /**
     * Create new service.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ServiceRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('services::service.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('services/service/' . $service->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the service.
     *
     * @param Request $request
     * @param Model   $service
     *
     * @return Response
     */
    public function update(ServiceRequest $request, Service $service)
    {
        try {
            $data = $request->all();

            $service->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('services::service.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('services/service/' . $service->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service/' . $service->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the service.
     *
     * @param Model   $service
     *
     * @return Response
     */
    public function destroy(ServiceRequest $request, Service $service)
    {
        try {
            $service->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('services::service.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('services/service/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service/' . $service->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
