<?php

namespace Litepie\Services\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litepie\Services\Http\Requests\ServiceReviewRequest;
use Litepie\Services\Interfaces\ServiceReviewRepositoryInterface;
use Litepie\Services\Models\ServiceReview;
use Litepie\Services\Forms\ServiceReview as Form;

/**
 * APIController  class for service_review.
 */
class ServiceReviewAPIController extends BaseController
{

    /**
     * Initialize service_review resource controller.
     *
     * @param type ServiceReviewRepositoryInterface $service_review
     *
     * @return null
     */
    public function __construct(ServiceReviewRepositoryInterface $service_review)
    {
        parent::__construct();
        $this->repository = $service_review;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Services\Repositories\Criteria\ServiceReviewResourceCriteria::class);
    }

    /**
     * Display a list of service_review.
     *
     * @return Response
     */
    public function index(ServiceReviewRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litepie\Services\Repositories\Presenter\ServiceReviewPresenter::class)
            ->paginate();
    }

    /**
     * Display service_review.
     *
     * @param Request $request
     * @param Model   $service_review
     *
     * @return Response
     */
    public function show(ServiceReviewRequest $request, ServiceReview $service_review)
    {
        return $service_review->setPresenter(\Litepie\Services\Repositories\Presenter\ServiceReviewListPresenter::class);
        ;
    }

    /**
     * Create new service_review.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ServiceReviewRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('services::service_review.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('services/service_review/' . $service_review->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service_review');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the service_review.
     *
     * @param Request $request
     * @param Model   $service_review
     *
     * @return Response
     */
    public function update(ServiceReviewRequest $request, ServiceReview $service_review)
    {
        try {
            $data = $request->all();

            $service_review->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('services::service_review.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('services/service_review/' . $service_review->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service_review/' . $service_review->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the service_review.
     *
     * @param Model   $service_review
     *
     * @return Response
     */
    public function destroy(ServiceReviewRequest $request, ServiceReview $service_review)
    {
        try {
            $service_review->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('services::service_review.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('services/service_review/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('services/service_review/' . $service_review->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
