<?php

namespace Litepie\Services\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepie\Services\Models\ServiceReview;

class ServiceReviewPolicy
{

    /**
     * Determine if the given user can view the service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function view(UserPolicy $user, ServiceReview $service_review)
    {
        if ($user->canDo('services.service_review.view') && $user->isAdmin()) {
            return true;
        }

        return $service_review->user_id == user_id() && $service_review->user_type == user_type();
    }

    /**
     * Determine if the given user can create a service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('services.service_review.create');
    }

    /**
     * Determine if the given user can update the given service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function update(UserPolicy $user, ServiceReview $service_review)
    {
        if ($user->canDo('services.service_review.edit') && $user->isAdmin()) {
            return true;
        }

        return $service_review->user_id == user_id() && $service_review->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ServiceReview $service_review)
    {
        return $service_review->user_id == user_id() && $service_review->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ServiceReview $service_review)
    {
        if ($user->canDo('services.service_review.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given service_review.
     *
     * @param UserPolicy $user
     * @param ServiceReview $service_review
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ServiceReview $service_review)
    {
        if ($user->canDo('services.service_review.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
